@@ -3,6 +3,7 @@ import subprocess
 
 if sys.platform == 'linux2':
     import pynotify as notify
+    import gtk
 else:
     import Growl as notify
 
@@ -17,7 +18,11 @@ def display_notification(command, return_code):
         g.register()
         g.notify('command_finished', command, description)
     elif hasattr(notify, 'Notification'):
-        notification = notify.Notification(command, description)
+        if return_code == 0:
+            icon = gtk.STOCK_DIALOG_INFO
+        else:
+            icon = gtk.STOCK_DIALOG_ERROR
+        notification = notify.Notification(command, description, icon)
         notification.show()
 
 def main():
